/*==============================================================*/
/* Volume Migration                                             */
/*==============================================================*/

INSERT INTO UI_VIEW_RESOURCE_R
ON EXISTING UPDATE VALUES  ('A_VM_FAILED_RID');

INSERT INTO UI_VIEW_RESOURCE_R
ON EXISTING UPDATE VALUES  ('B_VM_RUNNING_RID');

INSERT INTO UI_VIEW_RESOURCE_R
ON EXISTING UPDATE VALUES  ('C_VM_NOTSTARTED_RID');

INSERT INTO UI_VIEW_RESOURCE_R
ON EXISTING UPDATE VALUES  ('D_VM_COMPLETED_RID');

INSERT INTO UI_VIEW_RESOURCE_R
ON EXISTING UPDATE VALUES  ('E_VM_ABORTED_RID');

INSERT INTO UI_VIEW_ENUM_DEF_R (OBJECT, PROPERTY, VALUE, RESOURCE_ID)
ON EXISTING UPDATE VALUES  ('VM_JOBSTATE', 'STATUS', 'job_failed', 'A_VM_FAILED_RID');

INSERT INTO UI_VIEW_ENUM_DEF_R (OBJECT, PROPERTY, VALUE, RESOURCE_ID)
ON EXISTING UPDATE VALUES  ('VM_JOBSTATE', 'STATUS', 'job_running', 'B_VM_RUNNING_RID');

INSERT INTO UI_VIEW_ENUM_DEF_R (OBJECT, PROPERTY, VALUE, RESOURCE_ID)
ON EXISTING UPDATE VALUES  ('VM_JOBSTATE', 'STATUS', 'job_not_started', 'C_VM_NOTSTARTED_RID');

INSERT INTO UI_VIEW_ENUM_DEF_R (OBJECT, PROPERTY, VALUE, RESOURCE_ID)
ON EXISTING UPDATE VALUES  ('VM_JOBSTATE', 'STATUS', 'job_completed', 'D_VM_COMPLETED_RID');

INSERT INTO UI_VIEW_ENUM_DEF_R (OBJECT, PROPERTY, VALUE, RESOURCE_ID)
ON EXISTING UPDATE VALUES  ('VM_JOBSTATE', 'STATUS', 'job_aborted', 'E_VM_ABORTED_RID');


/*==============================================================*/
/* View: SF_VIEW_UI_VOLMGR1_STATUS                   	        */
/*==============================================================*/

IF EXISTS(SELECT 1 FROM SYS.SYSTABLE WHERE TABLE_NAME='SF_VIEW_VOLMGR1_STATUS_R' AND TABLE_TYPE='VIEW') THEN
   DROP VIEW SF_VIEW_VOLMGR1_STATUS_R
END IF;

CREATE VIEW SF_VIEW_VOLMGR1_STATUS_R AS
SELECT 
   SOL.ID AS ID, 
   SOL.NAME AS NAME, 
   SOL.DESCR AS DESCR, 
   SOL.USER_ID AS USER_ID, 
   SOL.START_TIME AS START_TIME, 
   SOL.LAST_UPDATE_TIME AS LAST_UPDATE_TIME, 
   SOL.DATA AS DATA, 
   COUNT(JOB.ID) AS JOB_COUNT, 
   SUM(IF(JOB.STATUS='job_completed')THEN 1 ELSE 0 ENDIF) AS COMPLETED_JOB_COUNT, 
   SUM(IF(JOB.STATUS='job_failed')THEN 1 ELSE 0 ENDIF) AS FAILED_JOB_COUNT, 
   ((COMPLETED_JOB_COUNT + FAILED_JOB_COUNT) * 100 / JOB_COUNT) AS PERCENT_COMPLETE,
   IF(SOL.STATUS='job_completed' AND FAILED_JOB_COUNT > 0) THEN 'job_failed' ELSE SOL.STATUS ENDIF AS VOLMGR_STATUS,
   '$^' + SOL.NAME + '$^' + SOL.USER_ID + '$^' AS SEARCH_KEY 
FROM SF_VIEW_SOLUTION_R SOL 
INNER JOIN HABDBSYNC.SF_VIEW_SOLUTION_JOB_R JOB ON JOB.SOLUTION_ID = SOL.ID AND (JOB.COMMAND = 'vrts.cm.volmgr.solution.MoveVolOperation' OR JOB.COMMAND = 'vrts.cm.voltmpl.solution.ProvisionStorageOperation') 
WHERE (SOL.MASTER_ID = 'VOL_TMPL') AND (SOL.ID LIKE '%_VOLMGR_1' OR SOL.ID LIKE '%_STOPROV_1') 
GROUP BY SOL.ID, SOL.NAME, SOL.DESCR, SOL.USER_ID, SOL.START_TIME, SOL.STATUS, SOL.LAST_UPDATE_TIME, SOL.DATA, SOL.STATUS

GRANT SELECT ON SF_VIEW_VOLMGR1_STATUS_R TO HABGUEST;
GRANT DELETE,INSERT,UPDATE,SELECT ON SF_VIEW_VOLMGR1_STATUS_R TO HABGUI;
GRANT DELETE,INSERT,UPDATE,SELECT ON SF_VIEW_VOLMGR1_STATUS_R TO HABADM;
GRANT DELETE,INSERT,UPDATE,SELECT ON SF_VIEW_VOLMGR1_STATUS_R TO HABDBSYNC;




IF EXISTS(SELECT 1 FROM SYS.SYSTABLE WHERE TABLE_NAME='SF_VIEW_UI_VOLMGR1_STATUS' AND TABLE_TYPE='VIEW') THEN
   DROP VIEW SF_VIEW_UI_VOLMGR1_STATUS
END IF;

CREATE VIEW SF_VIEW_UI_VOLMGR1_STATUS AS
SELECT 
   SOL.ID AS ID, 
   SOL.NAME AS NAME, 
   SOL.DESCR AS DESCR, 
   SOL.USER_ID AS USER_ID, 
   SOL.START_TIME AS START_TIME, 
   SOL.LAST_UPDATE_TIME AS LAST_UPDATE_TIME, 
   SOL.DATA AS DATA, 
   SOL.JOB_COUNT AS JOB_COUNT, 
   SOL.COMPLETED_JOB_COUNT AS COMPLETED_JOB_COUNT, 
   SOL.FAILED_JOB_COUNT AS FAILED_JOB_COUNT, 
   SOL.PERCENT_COMPLETE AS PERCENT_COMPLETE,
   SOL.VOLMGR_STATUS AS STATUS,
   LOCALE.ID AS LOCALE_ID, 
   RB.DISPLAY AS DISPLAY_STATUS, 
   SOL.SEARCH_KEY + RB.DISPLAY + '$^' AS SEARCH_KEY 
FROM SF_VIEW_VOLMGR1_STATUS_R SOL
LEFT OUTER JOIN HABDBSYNC.UI_VIEW_SUPP_LOCALE_R LOCALE ON LOCALE.ID IS NOT NULL 
LEFT OUTER JOIN HABDBSYNC.UI_VIEW_ENUM_DEF_R ENUM ON ENUM.OBJECT = 'VM_JOBSTATE' AND ENUM.PROPERTY = 'STATUS' AND ENUM.VALUE = SOL.VOLMGR_STATUS 
LEFT OUTER JOIN HABDBSYNC.UI_VIEW_RES_BUNDLE_R RB ON ENUM.RESOURCE_ID = RB.ID AND LOCALE.ID = RB.LOCALE_ID 

GRANT SELECT ON SF_VIEW_UI_VOLMGR1_STATUS TO HABGUEST;
GRANT DELETE,INSERT,UPDATE,SELECT ON SF_VIEW_UI_VOLMGR1_STATUS TO HABGUI;
GRANT DELETE,INSERT,UPDATE,SELECT ON SF_VIEW_UI_VOLMGR1_STATUS TO HABADM;
GRANT DELETE,INSERT,UPDATE,SELECT ON SF_VIEW_UI_VOLMGR1_STATUS TO HABDBSYNC;

COMMIT;

/*==============================================================*/
/* Volume Migration                                             */
/*==============================================================*/

INSERT INTO UI_VIEW_RES_BUNDLE_R
ON EXISTING UPDATE VALUES  ('A_VM_FAILED_RID', 'en_US', 'Failed');

INSERT INTO UI_VIEW_RES_BUNDLE_R
ON EXISTING UPDATE VALUES  ('B_VM_RUNNING_RID', 'en_US', 'Running');

INSERT INTO UI_VIEW_RES_BUNDLE_R
ON EXISTING UPDATE VALUES  ('C_VM_NOTSTARTED_RID', 'en_US', 'Not Started');

INSERT INTO UI_VIEW_RES_BUNDLE_R
ON EXISTING UPDATE VALUES  ('D_VM_COMPLETED_RID', 'en_US', 'Completed');

INSERT INTO UI_VIEW_RES_BUNDLE_R
ON EXISTING UPDATE VALUES  ('E_VM_ABORTED_RID', 'en_US', 'Aborted');

COMMIT;
/*==============================================================*/
/* Volume Migration                                             */
/*==============================================================*/

-- INSERT INTO UI_VIEW_RES_BUNDLE_R ON EXISTING UPDATE VALUES ('A_VM_FAILED_RID', 'ja_JP', '[欺義 Faileddd 拒]');

-- INSERT INTO UI_VIEW_RES_BUNDLE_R ON EXISTING UPDATE VALUES ('B_VM_RUNNING_RID', 'ja_JP', '[欺義 Runningggg 拒]');

-- INSERT INTO UI_VIEW_RES_BUNDLE_R ON EXISTING UPDATE VALUES ('C_VM_NOTSTARTED_RID', 'ja_JP', '[欺義 Not Starteddddd 拒]');

-- INSERT INTO UI_VIEW_RES_BUNDLE_R ON EXISTING UPDATE VALUES ('D_VM_COMPLETED_RID', 'ja_JP', '[欺義 Completedddd 拒]');

-- INSERT INTO UI_VIEW_RES_BUNDLE_R ON EXISTING UPDATE VALUES ('E_VM_ABORTED_RID', 'ja_JP', '[欺義 Abortedddd 拒]');

COMMIT;
/*==============================================================*/
/* Volume Migration                                             */
/*==============================================================*/

-- INSERT INTO UI_VIEW_RES_BUNDLE_R ON EXISTING UPDATE VALUES ('A_VM_FAILED_RID', 'zh_CN', '[乗乣 Faileddd 倯]');

-- INSERT INTO UI_VIEW_RES_BUNDLE_R ON EXISTING UPDATE VALUES ('B_VM_RUNNING_RID', 'zh_CN', '[乗乣 Runningggg 倯]');

-- INSERT INTO UI_VIEW_RES_BUNDLE_R ON EXISTING UPDATE VALUES ('C_VM_NOTSTARTED_RID', 'zh_CN', '[乗乣 Not Starteddddd 倯]');

-- INSERT INTO UI_VIEW_RES_BUNDLE_R ON EXISTING UPDATE VALUES ('D_VM_COMPLETED_RID', 'zh_CN', '[乗乣 Completedddd 倯]');

-- INSERT INTO UI_VIEW_RES_BUNDLE_R ON EXISTING UPDATE VALUES ('E_VM_ABORTED_RID', 'zh_CN', '[乗乣 Abortedddd 倯]');

COMMIT;
